@@ -10,7 +10,7 @@ use Scalar::Util 'looks_like_number';
 use Text::ANSI::Util qw(ta_mbswidth_height ta_mbpad ta_add_color_resets
                         ta_mbwrap);
 
-our $VERSION = '0.22'; # VERSION
+our $VERSION = '0.23'; # VERSION
 
 my $ATTRS = [qw(
 
@@ -167,8 +167,18 @@ sub BUILD {
     # pick a default border style
     unless ($self->{border_style}) {
         my $bs;
+        my $force_utf8;
         if (defined $ENV{ANSITABLE_BORDER_STYLE}) {
             $bs = $ENV{ANSITABLE_BORDER_STYLE};
+        } elsif ($self->detect_terminal->{emulator_engine} eq 'linux' &&
+                     !defined($ENV{UTF8})) {
+            # even though Term::Detect::Software decides that linux virtual
+            # console does not support unicode, it actually can display some uni
+            # characters like single borders, so we use it as the default here
+            # instead of singleo_ascii (linux vc doesn't seem to support
+            # box_chars).
+            $force_utf8 = 1;
+            $bs = 'Default::singleo_utf8';
         } elsif ($self->{use_utf8}) {
             $bs = 'Default::bricko';
         } elsif ($self->{use_box_chars}) {
@@ -176,7 +186,11 @@ sub BUILD {
         } else {
             $bs = 'Default::singleo_ascii';
         }
-        $self->border_style($bs);
+
+        {
+            local $self->{use_utf8} = 1 if $force_utf8;
+            $self->border_style($bs);
+        }
     }
 
     # pick a default color theme
@@ -1292,7 +1306,7 @@ Text::ANSITable - Create a nice formatted table using extended ASCII and ANSI co
 
 =head1 VERSION
 
-version 0.22
+version 0.23
 
 =head1 SYNOPSIS
 
